@@ -905,6 +905,7 @@ sub WriteXMP($$;$)
         }
     }
     foreach $tagInfo (@tagInfoList) {
+        my @delPaths;   # list of deleted paths
         my $tag = $$tagInfo{TagID};
         my $path = GetPropertyPath($tagInfo);
         unless ($path) {
@@ -1033,7 +1034,7 @@ sub WriteXMP($$;$)
             # take attributes from old values if they exist
             %attrs = %{$$cap[1]};
             if ($overwrite) {
-                my ($delPath, $oldLang, $delLang, $addLang, @matchingPaths);
+               my ($oldLang, $delLang, $addLang, @matchingPaths);
                 # check to see if this is an indexed list item
                 if ($path =~ / /) {
                     my $pp;
@@ -1092,10 +1093,8 @@ sub WriteXMP($$;$)
                     }
                     # save attributes and path from first deleted property
                     # so we can replace it exactly
-                    unless ($delPath) {
-                        %attrs = %$attrs;
-                        $delPath = $path;
-                    }
+                    %attrs = %$attrs unless @delPaths;
+                    push @delPaths, $path;
                     # delete this tag
                     delete $capture{$path};
                     ++$changed;
@@ -1106,9 +1105,9 @@ sub WriteXMP($$;$)
                         delete $capture{"$pp/rdf:type"} if @a == 1;
                     }
                 }
-                next unless $delPath or $$tagInfo{List} or $addLang;
-                if ($delPath) {
-                    $path = $delPath;
+                next unless @delPaths or $$tagInfo{List} or $addLang;
+                if (@delPaths) {
+                    $path = shift @delPaths;
                     $deleted = 1;
                 } else {
                     # don't change tag if we couldn't delete old copy
@@ -1220,11 +1219,14 @@ sub WriteXMP($$;$)
             my $idx = $1;
             my $len = length $1;
             my $pos = pos($path) - $len - ($2 ? length $2 : 0);
-            # generate unique list sub-indices to store additional values in sequence
+            # use sub-indices if necessary to store additional values in sequence
             if ($subIdx) {
                 $idx = substr($idx, 0, -length($subIdx));   # remove old sub-index
                 $subIdx = substr($subIdx, 1) + 1;
                 $subIdx = length($subIdx) . $subIdx;
+            } elsif (@delPaths) {
+                $path = shift @delPaths;
+                next;
             } else {
                 $subIdx = '10';
             }
